pub struct OpClientError {
pub description: String,
pub validation_errors: Option<Vec<String>>,
pub status: Option<String>,
pub code: Option<u16>,
pub details: Option<HashMap<String, Value>>,
}Expand description
Error type for Open Payments client operations.
Fields
description- Human-readable error messagevalidation_errors- Optional list of validation error messagesstatus- HTTP status code (only relevant for HTTP errors)code- Error code (only relevant for HTTP errors)details- Additional error details as key-value pairs
Fields
description: StringHuman-readable error description.
validation_errors: Option<Vec<String>>Optional list of validation error messages.
status: Option<String>HTTP status (only relevant for HTTP errors).
code: Option<u16>Error code (only relevant for HTTP errors).
details: Option<HashMap<String, Value>>Additional error details as key-value pairs.
Implementations
Sourceimpl OpClientError
impl OpClientError
Sourcepub fn http(
description: impl Into<String>,
status: Option<String>,
code: Option<u16>,
) -> Self
pub fn http( description: impl Into<String>, status: Option<String>, code: Option<u16>, ) -> Self
Creates a new HTTP error with status code and optional error code.
Sourcepub fn validation(
description: impl Into<String>,
validation_errors: Vec<String>,
) -> Self
pub fn validation( description: impl Into<String>, validation_errors: Vec<String>, ) -> Self
Creates a new validation error with a list of validation messages.
Sourcepub fn other(description: impl Into<String>) -> Self
pub fn other(description: impl Into<String>) -> Self
Creates a new general error without HTTP-specific fields.
Sourcepub fn with_details(self, details: HashMap<String, Value>) -> Self
pub fn with_details(self, details: HashMap<String, Value>) -> Self
Adds additional details to the error.
Sourcepub fn with_detail(self, key: impl Into<String>, value: Value) -> Self
pub fn with_detail(self, key: impl Into<String>, value: Value) -> Self
Adds a single detail key-value pair to the error.